#
# spec file for package runc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define go_tool go

# MANUAL: Update the git_version and git_revision
# FIX-OPENSUSE: This will be removed as soon as we move Docker's runC fork into
#               a separate package. This whole versioning mess is caused by
#               Docker vendoring non-releases of runC.
%define git_version 9c2d8d1 
# How to get the git_revision
# git clone ${url}.git runc-upstream
# cd runc-upstream
# git checkout $git_version
# git_revision=r$(git rev-list HEAD | wc -l)
%define git_revision r2947
%define version_unconverted %{git_version}

Name:           runc
Version:        0.1.1+git%{git_revision}_%{git_version}
Release:        13.2
Summary:        Tool for spawning and running OCI containers
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/opencontainers/runc
Source:         %{name}-git.%{git_version}.tar.xz
Patch0:         CVE-2016-9962.patch
BuildRequires:  fdupes
# Make sure we require go 1.7
BuildRequires:  go-go-md2man
BuildRequires:  libapparmor-devel
BuildRequires:  golang(API) = 1.7
# Seccomp isn't supported on aarch64.
%ifnarch aarch64
BuildRequires:  libseccomp-devel
%endif
BuildRequires:  libselinux-devel
Recommends:     criu
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
runc is a CLI tool for spawning and running containers according to the OCI
specification. It is designed to be as minimal as possible, and is the workhorse
of Docker. It was originally designed to be a replacement for LXC within Docker,
and has grown to become a separate project entirely.

%package test
Summary:        Test package for runc
# Make sure we require go 1.7
Group:          System/Management
BuildRequires:  golang(API) = 1.7
Requires:       go-go-md2man
Requires:       libapparmor-devel
# Seccomp isn't supported on aarch64.
%ifnarch aarch64
Requires:       libseccomp-devel
%endif
Requires:       libselinux-devel
Recommends:     criu
BuildArch:      noarch

%description test
Test package for runc. It contains the source code and the tests.

%prep
%setup -q -n %{name}-git.%{git_version}
%patch0 -p1

%build
# Do not use symlinks. If you want to run the unit tests for this package at
# some point during the build and you need to directly use go list directly it
# will get confused by symlinks.
export GOPATH=${HOME}/go:${HOME}/go/src/github.com/opencontainers/runc/Godeps/_workspace
mkdir -pv $HOME/go/src/github.com/opencontainers/runc
rm -rf $HOME/go/src/github.com/opencontainers/runc/*
cp -avr * $HOME/go/src/github.com/opencontainers/runc

export BUILDFLAGS="-gccgoflags=-Wl,--add-needed -Wl,--no-as-needed -static-libgo -ldl -lselinux -lapparmor"
# Build all features.
export BUILDTAGS="apparmor selinux"

# Seccomp isn't supported on aarch64.
%ifnarch aarch64
export BUILDTAGS="$BUILDTAGS seccomp"
export BUILDFLAGS="$BUILDFLAGS -lseccomp"
%endif

# Build runc.
%go_tool build "$BUILDFLAGS" -tags "$BUILDTAGS" -x -o %{name}-%{version} github.com/opencontainers/%{name}

# Build man pages, this can only be done on arches where we can build go-md2man.
man/md2man-all.sh

%check
export GOPATH=$HOME/go/src/github.com/opencontainers/runc/Godeps/_workspace:$GOPATH
cd $HOME/go/src/github.com/opencontainers/runc
PKG_LIST=$(go list ./... \
		| grep -v 'github.com/opencontainers/runc/libcontainer/cgroups/fs$' \
		| grep -v 'github.com/opencontainers/runc/libcontainer$' \
		| grep -v 'github.com/opencontainers/runc/libcontainer/integration$' \
		| grep -v 'github.com/opencontainers/runc/libcontainer/nsenter$' \
		| grep -v 'github.com/opencontainers/runc/libcontainer/user$' \
		| grep -v 'github.com/opencontainers/runc/libcontainer/xattr$')
go test -timeout 3m -tags "$BUILDTAGS" -v $PKG_LIST

%install
install -D -m755 %{name}-%{version} %{buildroot}%{_sbindir}/%{name}
install -d -m755 %{buildroot}/usr/src/runc/
cp -avr $HOME/go/src/github.com/opencontainers/runc/* %{buildroot}/usr/src/runc/

# symlink runc as docker-runc. bsc#1015661
install -d -m755 %{buildroot}/%{_bindir}
ln -s /usr/sbin/runc %{buildroot}/%{_bindir}/docker-runc 

install -d -m755 %{buildroot}%{_mandir}/man8
install -m644 man/man8/runc*.8 %{buildroot}%{_mandir}/man8

%fdupes %{buildroot}/%{_prefix}

%post

%files
%defattr(-,root,root)
%doc README.md LICENSE
%{_sbindir}/%{name}
%{_bindir}/docker-runc

%{_mandir}/man8/runc*.8.gz

%files test
%defattr(-,root,root)
/usr/src/runc/
%exclude /usr/src/runc/runc
%exclude /usr/src/runc/runc/Godeps/_workspace/pkg

%changelog
* Thu May  4 2017 jmassaguerpla@suse.com
- fix the golang requirement to 1.7 to the subpackages
* Tue May  2 2017 jmassaguerpla@suse.com
- fix golang requirement to 1.7
* Fri Apr 28 2017 jengelh@inai.de
- Substitute %%__-type macro indirections
* Thu Apr 13 2017 jmassaguerpla@suse.com
- update version to the one required by docker-17.04.0-ce (bsc#1034053)
  remove ignore_cgroup2_mountpoint.patch . This is already included in
  the upstream source code.
* Wed Apr 12 2017 jmassaguerpla@suse.com
- Make sure this is being built with go 1.7
* Tue Apr 11 2017 jmassaguerpla@suse.com
- remove the go_arches macro because we are using go1.7 which
  is available in all archs
* Wed Mar 29 2017 jmassaguerpla@suse.com
- fix bsc#1028113 - runc: make sure to ignore cgroup v2 mountpoints
  This is a backport of https://github.com/opencontainers/runc/pull/1266
  + ignore_cgroup2_mountpoint.patch
* Fri Feb 24 2017 jmassaguerpla@suse.com
- update to docker-1.13.0 requirement
* Fri Jan 13 2017 jmassaguerpla@suse.com
- fix CVE-2016-9962 bsc#1012568 and applying the patch
  CVE-2016-9962.patch, because 1.12.6 partially fixes it (it contains
  the first patch attached in bsc#1012568)
* Mon Dec 19 2016 jmassaguerpla@suse.com
- update runc to the version used in docker 1.12.5 (bsc#1016307).
  This fixes bsc#1015661
* Mon Dec 19 2016 asarai@suse.com
- For the moment, we have to switch to using Docker's fork of runC. This *will*
  be solved properly by creating a new package purely for Docker's runC fork,
  because it's quite silly to tie OCI project releases to Docker's vendoring
  scheme. Once this is fixed, this package will be switch to being purely-OCI.
* Fri Dec 16 2016 jmassaguerpla@suse.com
- add the /usr/bin/docker-run symlink to partially fix bsc#1015661
* Thu Nov 24 2016 jmassaguerpla@suse.com
- fix version by adding a revision "counter" so that it will always
  increase
  fix bsc#1009961
* Thu Oct 13 2016 jmassaguerpla@suse.com
- update to 02f8fa7 because that is the needed version for docker 1.12.1 (bsc#1004490)
* Wed Sep 21 2016 jengelh@inai.de
- Run fdupes.
* Mon Sep 19 2016 jmassaguerpla@suse.com
- fix go_arches definition: use global instead of define, otherwise
  it fails to build
* Fri Aug 26 2016 asarai@suse.com
- Remove docker-runc symlink because it's been fixed within the Docker
  package. bsc#978260
* Thu Aug 25 2016 jmassaguerpla@suse.com
- Create a symlink /usr/sbin/docker-runc -> /usr/sbin/docker
  Docker expects this symlink to exist bsc#978260
* Thu Aug 25 2016 jmassaguerpla@suse.com
- Remove GOPATH at the end of the GOPATH assignment
  cause GOPATH is empty and if we do that, we get the path ""
  appended, which causes gcc6-go to complain
* Wed Aug 24 2016 jmassaguerpla@suse.com
- add go_arches in project configuration: this way, we can use the
  same spec file but decide in the project configuration if to
  use gc-go or gcc-go for some archs.
* Thu Aug 18 2016 jmassaguerpla@suse.com
- use gcc6-go instead of gcc5-go (bsc#988408)
- build ppc64le with gc-go because this version builds with gc-go 1.6
* Thu Aug 18 2016 cbrauner@suse.de
- bump git commit id to the one required by docker v1.12.0 (bsc#995058)
- run unit tests during package build
- remove seccomp-use-pkg-config.patch
  The patch is now upstream.
- remove GO_BUILD_FLAGS macro and substitute with BUILDFLAGS env variable to
  allow for easier string appending.
- only run unit test on architectures that provide the go list and go test tools
* Wed Aug 17 2016 cbrauner@suse.de
- Add runc-test package which contains the source code and the test. This
  package will be used to run the integration tests.
- Simplify package build and check sections: Instead of symlinking we default to
  cp -avr. go list gets confused by symlinks hence, we need to copy the source
  code anyway if we want to run unit tests during package build at some point.
* Fri Apr 29 2016 asarai@suse.de
  * Update to runC 0.1.1. (bsc#989566 FATE#320763) Changelog from upstream:
  This release includes a bug fix for adding the selinux mount label in the specification.
* Tue Apr 19 2016 asarai@suse.de
  * Don't use gcc-go for aarch64, since gc has grown support for it and is more
  stable.
* Fri Apr 15 2016 asarai@suse.de
  * Disable seccomp entirely for aarch64 builds, since it is not provided on all
  SUSE platforms.
* Wed Apr 13 2016 asarai@suse.de
  * Update to runC 0.1.0. Changelog from upstream:
  This release updates runc to the OCI runtime specification v0.5.0 and includes
  various fixes and features.
  Features:
  + cgroups: pid limits and stats
  + cgroups: kmem stats
  + systemd cgroup support
  + libcontainer specconv package
  + no pivot root option
  + numeric ids are treated as uid/gid
  + hook improvements
  Bug Fixes:
  * log flushing
  * atomic pid file creation
  * init error recovery
  * seccomp logging removed
  * delete container on aborted start
  * /dev bind mount handling
* Wed Mar 30 2016 asarai@suse.de
  * Install to /usr/sbin.  https://github.com/opencontainers/runc/pull/702
* Sun Mar 27 2016 asarai@suse.de
  * Added runC man pages.
  * Recommended criu, since it's required for the checkpoint and restore
  functionality.
* Sun Mar 27 2016 asarai@suse.de
  * Small updates to method of compilation to better match Makefile.
* Mon Mar 21 2016 asarai@suse.de
  * Make compilation work on gcc-go only systems (ppc and s390).
* Mon Mar 21 2016 asarai@suse.de
  * initial import of runC 0.0.9
  * add patch seccomp-use-pkg-config.patch which allows us to build runC, since
  they assume that the seccomp.h file lives at /usr/include/seccomp.h.
